@@ -1,6 +1,10 @@
-from django.utils import simplejson
 from bambu.webhooks.sites import WebHookSite, NotRegistered
 
+try:
+	import json as simplejson
+except ImportError:
+	from django.utils import simplejson
+
 site = WebHookSite()
 
 def send(hook, user, data = {}, hash = None):
